@@ -1,3 +1,21 @@
+# Copyright © 2022 CISPA Helmholtz Center for Information Security.
+# Author: Dominic Steinhöfel.
+#
+# This file is part of ISLa.
+#
+# ISLa is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# ISLa is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with ISLa.  If not, see <http://www.gnu.org/licenses/>.
+
 import copy
 import functools
 import importlib.resources
@@ -658,6 +676,9 @@ class Maybe(Generic[T], MonadPlus[Optional[T]]):
             raise AttributeError("No element present")
         return self.a
 
+    def get_unsafe(self) -> Optional[T]:
+        return self.a
+
     def __add__(
         self,
         other: "Maybe[T]" | Tuple[Callable[[S, ...], "Maybe[T]"], S],
@@ -669,6 +690,9 @@ class Maybe(Generic[T], MonadPlus[Optional[T]]):
         assert callable(other[0])
         return self.lazy_mplus(*other)
 
+    def __bool__(self):
+        return self.is_present()
+
 
 E = TypeVar("E", bound=Exception)
 
